#ifndef CAMERA_H
#define CAMERA_H

#include <SDL.h>
#include <glm.hpp>

#include "GameObject.h"

struct PlaneInfo {
    glm::vec3 plane;
    glm::vec3 pointOnPlane;
};


class Camera {
    public:
		Camera(glm::vec3 position);
		~Camera();
        void move(const Uint8* currentKeyStates);
        void lookAt(float dx, float dy);
        glm::mat4 getViewMatrix();
        glm::mat4 getProjectionMatrix();
		glm::vec3 getViewDirection();
		glm::vec3 getPosition();
        void setProjectionMatrix(float angle, float ratio, float nearPlaneDist, float farPlaneDist);
		float getRadius();
        //bool isInViewFrustum(BoundingBox bb);

    private:
        //void updateViewFrustum();
        //float getPlanePointDistance(PlaneInfo planeInfo, glm::vec3 point);
        glm::vec3 position;
        glm::vec3 center;
        glm::vec3 up;
        float nearPlaneDistance;
        float farPlaneDistance;
        float frustumAngle;
        float nearPlaneHeight;
        float farPlaneHeight;
        float nearPlaneWidth;
        float farPlaneWidth;
        float ratio;
        std::vector<PlaneInfo> frustumPlanes;
        float velocity;
        glm::mat4 projectionMatrix;

};

#endif